@@ -8,7 +8,7 @@ class LoginApi:
         self.__timeout = timeout
         self.__username = username
         self.__password = password
-        self.__login_url = 'http://www.rainiee.com/api/v1.0/api-token-auth'
+        self.__login_url = 'https://data.rainiee.com/api/v1.0/api-token-auth'
 
     def login(self):
         res = requests.get(self.__login_url, params={'username': self.__username, 'password': self.__password},
