@@ -5,10 +5,12 @@ TOKEN_F_P = 'rainiee_data.token'
 
 def set_token(token):
     user_home = os.path.expanduser('~')
-    with open(user_home + TOKEN_F_P, 'w') as f:
+    path = os.path.join(user_home, TOKEN_F_P)
+    with open(path, 'w') as f:
         f.write(token)
 
 def get_token():
     user_home = os.path.expanduser('~')
-    with open(user_home+TOKEN_F_P, 'r') as f1:
+    path = os.path.join(user_home, TOKEN_F_P)
+    with open(path, 'r') as f1:
         return f1.readline()
